@@ -18,13 +18,13 @@ class ApiData():
         self.on_refs = None
         self.on_srefs = None
 
-    async def initialize(self, api_token, api_host):
+    async def initialize(self, api_token, api_host,scheme):
         """
         initialize the api with token for authentication and authorization
         """
         api_token = quote(api_token)
         print(api_token)
-        protocol = "http"
+        protocol = scheme
         host = api_host
         # host = "localhost:5011"
         hub_url = f"{protocol}://{host}/api/fda/apidata/stream?api_token={api_token}"
