@@ -17,9 +17,9 @@ async def main():
     api.on_refs_update(on_refs)
     api.on_srefs_update(on_srefs)
     
-    key = "l+phpXGgBZx/g3t+F0ZpW6xNJEA="
+    #key = "l+phpXGgBZx/g3t+F0ZpW6xNJEA="
     host = "apidata.accelpix.in"
-    #key="OMLW74kiRTZeuBIWiJ4gXKZPsPk="
+    key="vmuFRDRmyKXp2+Yt729KKgPBfC0="
     #host ="192.168.56.101"
     # host = "localhost:5011"
     s = await api.initialize(key, host,"http")
@@ -29,15 +29,14 @@ async def main():
     his1 = await api.get_eod('TCS', '20200828', '20200901')
     print("History : ",his1)
 
-    master = await api.getMaster()
-    print(master)
+
     #end
 
     #Live data
-    syms = ["TCS",'NIFTY-1']
+    syms = ['5PAISA']
     await api.subscribeAll(syms)
-    time.sleep(1)
-    await api.unsubscribeAll(['TCS'])
+    #time.sleep(1)
+    #await api.unsubscribeAll(['TCS'])
     print("=====Unsubscribe Done=====")
     
 
@@ -50,19 +49,19 @@ def connection_stopped():
 
 def on_trade(msg):
     t = apidata_models.Trade(msg)
-    print("Trade :",t.ticker)#trade
+    #print("Trade :",t.ticker)#trade
 
 def on_best(msg):
     b = apidata_models.Best(msg)
-    print("best :",msg)#best
+    #print("best :",msg)#best
 
 def on_refs(msg):
     ref = apidata_models.Refs(msg)
-    print("refs",msg)#refs
+    #print("refs",msg)#refs
 
 def on_srefs(msg):
     sref = apidata_models.RefsSnapshot(msg)
-    print("sref:",msg)
+    print("sref:",sref.upc)
 #end
 
 event_loop.create_task(main())
